@@ -489,10 +489,6 @@ pub mod instructions {
         pool_account: Pubkey,
         pool_coin_token_account: Pubkey,
         pool_pc_token_account: Pubkey,
-        pool_lp_mint :Pubkey,
-        user_coin_token_account: Pubkey,
-        user_pc_token_account: Pubkey,
-        user_lp_token_account: Pubkey,
         user_authority: Pubkey,
         market: Pubkey,
         open_orders: Pubkey,
@@ -507,14 +503,10 @@ pub mod instructions {
         Instruction {
             program_id: addresses::POOL_PROGRAM_ID,
             accounts: vec![
-                AccountMeta::new_readonly(protocol_account, false),
+                AccountMeta::new(protocol_account, false),
                 AccountMeta::new(pool_account, false),
                 AccountMeta::new(pool_coin_token_account, false),
                 AccountMeta::new(pool_pc_token_account, false),
-                AccountMeta::new(pool_lp_mint, false),
-                AccountMeta::new(user_coin_token_account, false),
-                AccountMeta::new(user_pc_token_account, false),
-                AccountMeta::new(user_lp_token_account, false),
                 AccountMeta::new(user_authority, true),
                 AccountMeta::new(market, false),
                 AccountMeta::new(open_orders, false),
@@ -527,6 +519,7 @@ pub mod instructions {
                 AccountMeta::new_readonly(serum_vault_signer, false),
                 AccountMeta::new_readonly(spl_token::id(), false),
                 AccountMeta::new_readonly(SERUM_DEX_PROGRAM_ID, false),
+                AccountMeta::new_readonly(system_program::id(), false),
                 AccountMeta::new_readonly(sysvar::rent::id(), false),
             ],
             data: GlobalSighashDB.get("ix1").unwrap().to_vec(),
